@@ -33,22 +33,22 @@ double dburr(double x, double shape1, double shape2, double scale,
         return R_NaN;
 
     if (!R_FINITE(x) || x < 0.0)
-        return R_D__0;
+        return ACT_D__0;
 
     /* handle x == 0 separately */
     if (x == 0)
     {
 	if (shape2 < 1) return R_PosInf;
-	if (shape2 > 1) return R_D__0;
+	if (shape2 > 1) return ACT_D__0;
 	/* else */
-	return R_D_val(shape1 / scale);
+	return ACT_D_val(shape1 / scale);
     }
 
     tmp = shape2 * (log(x) - log(scale));
-    logu = - log1p(exp(tmp));
-    log1mu = - log1p(exp(-tmp));
+    logu = - log1pexp(tmp);
+    log1mu = - log1pexp(-tmp);
 
-    return R_D_exp(log(shape1) + log(shape2) + shape1 * logu
+    return ACT_D_exp(log(shape1) + log(shape2) + shape1 * logu
                    + log1mu - log(x));
 }
 
@@ -66,11 +66,11 @@ double pburr(double q, double shape1, double shape2, double scale,
         return R_NaN;
 
     if (q <= 0)
-        return R_DT_0;
+        return ACT_DT_0;
 
-    u = exp(-log1p(exp(shape2 * (log(q) - log(scale)))));
+    u = exp(-log1pexp(shape2 * (log(q) - log(scale))));
 
-    return R_DT_Cval(R_pow(u, shape1));
+    return ACT_DT_Cval(R_pow(u, shape1));
 }
 
 double qburr(double p, double shape1, double shape2, double scale,
@@ -84,10 +84,10 @@ double qburr(double p, double shape1, double shape2, double scale,
         scale  <= 0.0)
         return R_NaN;
 
-    R_Q_P01_boundaries(p, 0, R_PosInf);
-    p =  R_D_qIv(p);
+    ACT_Q_P01_boundaries(p, 0, R_PosInf);
+    p =  ACT_D_qIv(p);
 
-    return scale * R_pow(R_pow(R_D_Cval(p), -1.0/shape1) - 1.0, 1.0/shape2);
+    return scale * R_pow(R_pow(ACT_D_Cval(p), -1.0/shape1) - 1.0, 1.0/shape2);
 }
 
 double rburr(double shape1, double shape2, double scale)
@@ -151,9 +151,9 @@ double levburr(double limit, double shape1, double shape2, double scale,
     tmp2 = 1.0 + tmp1;
     tmp3 = shape1 - tmp1;
 
-    u = exp(-log1p(exp(shape2 * (log(limit) - log(scale)))));
+    u = exp(-log1pexp(shape2 * (log(limit) - log(scale))));
 
     return R_pow(scale, order) * gammafn(tmp2) * gammafn(tmp3)
         * pbeta(0.5 - u + 0.5, tmp2, tmp3, 1, 0) / gammafn(shape1)
-        + R_VG__0(limit, order) * R_pow(u, shape1);
+        + ACT_DLIM__0(limit, order) * R_pow(u, shape1);
 }
